@@ -192,7 +192,7 @@ class API:
 
     def dev_atts(
         self, attribute: str, value_type: Union[str, None] = None
-    ) -> Union[DeviceAttribute, None]:
+    ) -> Union[DeviceAttribute, str]:
         """Returns the DeviceAttribute object by attribute, camel case or not.
 
         :return: An object representing a device attribute.
@@ -206,7 +206,7 @@ class API:
             ),
             DeviceAttribute(attribute, HILO_READING_TYPES.get(value_type, ""))
             if value_type
-            else None,
+            else attribute,
         )
 
     def _get_fid_state(self) -> bool:
@@ -522,6 +522,7 @@ class API:
         if reg_id := reg_state.get("reg_id"):
             await self.delete_registration(reg_id)
         self._reg_id = await self.post_registration()
+        await self.delete_registration(self._reg_id)
         reg_dict: RegistrationDict = {"reg_id": self._reg_id}
         set_state(self._state_yaml, "registration", reg_dict)
         (self.ws_url, self.ws_token) = await self.post_devicehub_negociate()
